#define iChannel0 inputImageTexture
#define texture(a, b) texture2D(a, fract(b))
#define fragColor gl_FragColor

precision highp float;

varying vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform float blurRadius;
uniform vec2 iResolution;

float SCurve (float x) {
    x = x * 2.0 - 1.0;
    return -x * abs(x) * 0.5 + x + 0.5;
}

vec4 BlurH (sampler2D source, vec2 size, vec2 uv, float radius) {

    if (radius >= 1.0)
    {
        vec4 A = vec4(0.0);
        vec4 C = vec4(0.0);

        float width = 1.0 / size.x;

        float divisor = 0.0;
        float weight = 0.0;

        float radiusMultiplier = 1.0 / radius;

        for (float x = -radius; x <= radius; x++)
        {
            A = texture(source, uv + vec2(x * width, 0.0));

            weight = SCurve(1.0 - (abs(x) * radiusMultiplier));

            C += A * weight;

            divisor += weight;
        }

        return vec4(C.r / divisor, C.g / divisor, C.b / divisor, 1.0);
    }

    return texture(source, uv);
}

void main()
{
    // Apply vertical blur to buffer A
    fragColor = BlurH(iChannel0, iResolution.xy, textureCoordinate, blurRadius);
}