precision highp float;
precision mediump int;

uniform sampler2D sTexture;
uniform sampler2D u_Texture1;
varying vec2 vTexCoord;

uniform float opacity;

float eachcomponent(float Cb, float Cs, float Ab, float As) {
    float nonPremultiplyCb = Cb / (Ab + step(Ab, 0.0));
    float nonPremultiplyCs = Cs / (As + step(As, 0.0));

    if (nonPremultiplyCs <= 0.5) {
        if (nonPremultiplyCs == 0.0) {
            return 0.0;
        } else {
            return 1.0 - (1.0 - nonPremultiplyCb) / (2.0 * nonPremultiplyCs);
        }
    } else {
        if (nonPremultiplyCs == 1.0) {
            return 1.0;
        } else {
            return nonPremultiplyCb / (2.0 * (1.0 - nonPremultiplyCs));
        }
    }
}

vec3 blend(vec4 base, vec4 overlay) {
    float r = eachcomponent(base.r, overlay.r, base.a, overlay.a);
    float g = eachcomponent(base.g, overlay.g, base.a, overlay.a);
    float b = eachcomponent(base.b, overlay.b, base.a, overlay.a);
    vec3 color = clamp(vec3(r, g, b), 0.0, 1.0);
    return (1.0 - overlay.a) * base.rgb + (1.0 - base.a) * overlay.rgb + base.a * overlay.a * color;
}

void main()
{
    lowp vec4 base = texture2D(sTexture, vTexCoord);
    lowp vec4 overlay = texture2D(u_Texture1, vTexCoord) * opacity;

    gl_FragColor = vec4(blend(base, overlay), base.a + overlay.a - base.a * overlay.a);
}